@@ -13,9 +13,12 @@
 ##############################################################################
 """Bootstrap tests
 
-$Id: tests.py 87484 2008-06-18 00:50:10Z fdrake $
+$Id: tests.py 90010 2008-08-19 16:41:20Z fdrake $
 """
+import ZConfig
+import os.path
 import unittest
+import urllib
 import transaction
 
 import zope.component
@@ -45,7 +48,7 @@ class EventStub(object):
         self.database = db
 
 #
-# TODO: some methods from the boostap modue are not tested
+# TODO: some methods from the boostap module are not tested
 #
 
 class TestBootstrapSubscriber(PlacefulSetup, unittest.TestCase):
@@ -156,12 +159,37 @@ class TestBootstrapSubscriber(PlacefulSetup, unittest.TestCase):
 
         cx.close()
 
+
+class TestConfigurationSchema(unittest.TestCase):
+
+    def setUp(self):
+        self.here = os.path.dirname(os.path.abspath(__file__))
+        self.schema_dir = os.path.join(self.here, "schema")
+
+    def path2url(self, path):
+        urlpath = urllib.pathname2url(path)
+        while urlpath.startswith("/"):
+            urlpath = urlpath[1:]
+        return "file:///" + urlpath
+
+    def test_productconfig_xml(self):
+        path = os.path.join(self.schema_dir, "productconfig.xml")
+        url = self.path2url(path)
+        schema = ZConfig.loadSchema(url)
+
+    def test_schema_xml(self):
+        path = os.path.join(self.schema_dir, "schema.xml")
+        url = self.path2url(path)
+        schema = ZConfig.loadSchema(url)
+
+
 def bootstraptearDown(test):
     test.globs['db'].close()
 
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(TestBootstrapSubscriber))
+    suite.addTest(unittest.makeSuite(TestConfigurationSchema))
     suite.addTest(doctest.DocTestSuite(
         'zope.app.appsetup.appsetup',
         setUp=placelesssetup.setUp, tearDown=placelesssetup.tearDown))
